@@ -35,7 +35,7 @@ public slots:
     /** @brief Relay datachanged signal from view's model  */
     void slotDataChanged(const QModelIndex &ix1, const QModelIndex &ix2, const QVector<int> &roles);
     /** @brief Select all items in model */
-    void selectAll();
+    void selectAll(QModelIndex rootIndex = QModelIndex());
 
 private slots:
     /** @brief Called when a row change is detected by selection model */
