@@ -1,21 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2021 by Jean-Baptiste Mardelle (jb@kdenlive.org)        *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2021 Jean-Baptiste Mardelle <jb@kdenlive.org>
+
+SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "kdenlivesettingsdialog.h"
 #include "clipcreationdialog.h"
@@ -32,6 +19,7 @@
 #include "project/dialogs/profilewidget.h"
 #include "wizard.h"
 #include "monitor/monitor.h"
+#include "doc/kdenlivedoc.h"
 
 #ifdef USE_V4L
 #include "capture/v4lcapture.h"
@@ -67,6 +55,7 @@
 #include <QThread>
 #include <QTimer>
 #include <QtConcurrent>
+#include <QRegularExpression>
 #include <cstdio>
 #include <cstdlib>
 #include <fcntl.h>
@@ -120,8 +109,8 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(QMap<QString, QString> mappable_a
 
     m_configMisc.kcfg_use_exiftool->setEnabled(!QStandardPaths::findExecutable(QStringLiteral("exiftool")).isEmpty());
 
-    QRegExp rx(R"((\+|-)?\d{2}:\d{2}:\d{2}(:||,)\d{2})");
-    QValidator *validator = new QRegExpValidator(rx, this);
+    QRegularExpression reg(R"((\+|-)?\d{2}:\d{2}:\d{2}(:||,)\d{2})");
+    QValidator *validator = new QRegularExpressionValidator(reg, this);
     m_configMisc.kcfg_color_duration->setInputMask(pCore->timecode().mask());
     m_configMisc.kcfg_color_duration->setValidator(validator);
     m_configMisc.kcfg_title_duration->setInputMask(pCore->timecode().mask());
@@ -139,6 +128,21 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(QMap<QString, QString> mappable_a
     m_configMisc.kcfg_subtitle_duration->setInputMask(pCore->timecode().mask());
     m_configMisc.kcfg_subtitle_duration->setValidator(validator);
 
+    if (!KdenliveSettings::preferredcomposite().isEmpty()) {
+        int ix = m_configMisc.preferredcomposite->findData(KdenliveSettings::preferredcomposite());
+        if (ix > -1) {
+            m_configMisc.preferredcomposite->setCurrentIndex(ix);
+        }
+    }
+    connect(m_configMisc.preferredcomposite, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this,[&](){
+        if (m_configMisc.preferredcomposite->currentText() != KdenliveSettings::preferredcomposite()) {
+            KdenliveSettings::setPreferredcomposite(m_configMisc.preferredcomposite->currentText());
+            int mode = pCore->currentDoc()->getDocumentProperty(QStringLiteral("compositing")).toInt();
+            pCore->window()->getMainTimeline()->controller()->switchCompositing(mode);
+            pCore->currentDoc()->setModified();
+        }
+    });
+
     QWidget *p8 = new QWidget;
     m_configProject.setupUi(p8);
     m_page8 = addPage(p8, i18n("Project Defaults"));
@@ -347,6 +351,8 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(QMap<QString, QString> mappable_a
 
     loadEncodingProfiles();
 
+    connect(m_configSdl.fullscreen_monitor, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this,
+            &KdenliveSettingsDialog::slotSetFullscreenMonitor);
     connect(m_configSdl.kcfg_audio_driver, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this,
             &KdenliveSettingsDialog::slotCheckAlsaDriver);
     connect(m_configSdl.kcfg_audio_backend, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this,
@@ -778,6 +784,20 @@ void KdenliveSettingsDialog::initDevices()
         KdenliveSettings::setAudio_backend(ix);
     }
     m_configSdl.group_sdl->setEnabled(KdenliveSettings::audiobackend().startsWith(QLatin1String("sdl")));
+    
+    // Fill monitors data
+    QSignalBlocker bk(m_configSdl.fullscreen_monitor);
+    m_configSdl.fullscreen_monitor->clear();
+    m_configSdl.fullscreen_monitor->addItem(i18n("auto"));
+    for (const QScreen* screen : qApp->screens()) {
+        m_configSdl.fullscreen_monitor->addItem(QString("%1 %2 (%3)").arg(screen->manufacturer(), screen->model(), screen->name()), screen->serialNumber());
+    }
+    if (!KdenliveSettings::fullscreen_monitor().isEmpty()) {
+        int ix = m_configSdl.fullscreen_monitor->findData(KdenliveSettings::fullscreen_monitor());
+        if (ix > -1) {
+            m_configSdl.fullscreen_monitor->setCurrentIndex(ix);
+        }
+    }
 
     loadCurrentV4lProfileInfo();
 }
@@ -1126,7 +1146,7 @@ void KdenliveSettingsDialog::updateSettings()
         KdenliveSettings::setThumbColor1(m_configColors.kcfg_thumbColor1->color());
         KdenliveSettings::setThumbColor2(m_configColors.kcfg_thumbColor2->color());
         emit pCore->window()->getMainTimeline()->controller()->colorsChanged();
-        emit pCore->getMonitor(Kdenlive::ClipMonitor)->refreshAudioThumbs();
+        pCore->getMonitor(Kdenlive::ClipMonitor)->refreshAudioThumbs();
     }
 
     if (m_configSdl.kcfg_volume->value() != KdenliveSettings::volume()) {
@@ -1141,7 +1161,7 @@ void KdenliveSettingsDialog::updateSettings()
     if (m_configTimeline.kcfg_displayallchannels->isChecked() != KdenliveSettings::displayallchannels()) {
         KdenliveSettings::setDisplayallchannels(m_configTimeline.kcfg_displayallchannels->isChecked());
         emit audioThumbFormatChanged();
-        emit pCore->getMonitor(Kdenlive::ClipMonitor)->refreshAudioThumbs();
+        pCore->getMonitor(Kdenlive::ClipMonitor)->refreshAudioThumbs();
     }
 
     if (m_modified) {
@@ -1226,15 +1246,21 @@ void KdenliveSettingsDialog::updateSettings()
     settingsGroup.writeEntry("dialogSize", QVariant(size()));
 }
 
+void KdenliveSettingsDialog::slotSetFullscreenMonitor()
+{
+    QString value = m_configSdl.fullscreen_monitor->currentData().toString();
+    KdenliveSettings::setFullscreen_monitor(value);
+}
+
 void KdenliveSettingsDialog::slotCheckAlsaDriver()
 {
-    QString value = m_configSdl.kcfg_audio_driver->itemData(m_configSdl.kcfg_audio_driver->currentIndex()).toString();
+    QString value = m_configSdl.kcfg_audio_driver->currentData().toString();
     m_configSdl.kcfg_audio_device->setEnabled(value == QLatin1String("alsa"));
 }
 
 void KdenliveSettingsDialog::slotCheckAudioBackend()
 {
-    QString value = m_configSdl.kcfg_audio_backend->itemData(m_configSdl.kcfg_audio_backend->currentIndex()).toString();
+    QString value = m_configSdl.kcfg_audio_backend->currentData().toString();
     m_configSdl.group_sdl->setEnabled(value.startsWith(QLatin1String("sdl")));
 }
 
@@ -1818,7 +1844,7 @@ void KdenliveSettingsDialog::initSpeechPage()
     m_configSpeech.speech_info->setWordWrap(true);
     m_configSpeech.check_vosk->setIcon(QIcon::fromTheme(QStringLiteral("view-refresh")));
     m_configSpeech.check_vosk->setToolTip(i18n("Check VOSK installation"));
-    connect(m_configSpeech.check_vosk, &QPushButton::clicked, [this]() {
+    connect(m_configSpeech.check_vosk, &QPushButton::clicked, this, [this]() {
         m_configSpeech.check_vosk->setEnabled(false);
         KdenliveSettings::setVosk_found(false);
         KdenliveSettings::setVosk_srt_found(false);
@@ -1826,7 +1852,7 @@ void KdenliveSettingsDialog::initSpeechPage()
         m_configSpeech.check_vosk->setEnabled(true);
     });
     connect(this, &KdenliveSettingsDialog::showSpeechMessage, this, &KdenliveSettingsDialog::doShowSpeechMessage);
-    connect(m_voskAction, &QAction::triggered, [this]() {
+    connect(m_voskAction, &QAction::triggered, this, [this]() {
 #ifdef Q_OS_WIN
         QString pyExec = QStandardPaths::findExecutable(QStringLiteral("python"));
 #else
@@ -1862,7 +1888,7 @@ void KdenliveSettingsDialog::initSpeechPage()
         }
     });
     checkVoskDependencies();
-    connect(m_configSpeech.custom_vosk_folder, &QCheckBox::stateChanged, [this](int state) {
+    connect(m_configSpeech.custom_vosk_folder, &QCheckBox::stateChanged, this, [this](int state) {
         m_configSpeech.vosk_folder->setEnabled(state != Qt::Unchecked);
         if (state == Qt::Unchecked) {
             // Clear custom folder
@@ -1871,12 +1897,12 @@ void KdenliveSettingsDialog::initSpeechPage()
             slotParseVoskDictionaries();
         }
     });
-    connect(m_configSpeech.vosk_folder, &KUrlRequester::urlSelected, [this](QUrl url) {
+    connect(m_configSpeech.vosk_folder, &KUrlRequester::urlSelected, this, [this](QUrl url) {
         KdenliveSettings::setVosk_folder_path(url.toLocalFile());
         slotParseVoskDictionaries();
     });
     m_configSpeech.models_url->setText(i18n("Download speech models from: <a href=\"https://alphacephei.com/vosk/models\">https://alphacephei.com/vosk/models</a>"));
-    connect(m_configSpeech.models_url, &QLabel::linkActivated, [&](const QString &contents) {
+    connect(m_configSpeech.models_url, &QLabel::linkActivated, this, [&](const QString &contents) {
         qDebug()<<"=== LINK CLICKED: "<<contents;
 #if KIO_VERSION > QT_VERSION_CHECK(5, 70, 0)
         auto *job = new KIO::OpenUrlJob(QUrl(contents));
@@ -1953,7 +1979,7 @@ void KdenliveSettingsDialog::checkVoskDependencies()
                     QtConcurrent::run(this, &KdenliveSettingsDialog::checkVoskVersion, pyExec);
                 }
             }
-            pCore->updateVoskAvailability();
+            emit pCore->updateVoskAvailability();
         }
     } else {
         if (m_speechListWidget->count() == 0) {
@@ -2013,7 +2039,6 @@ void KdenliveSettingsDialog::getDictionary(const QUrl sourceUrl)
     if (url.isEmpty()) {
         return;
     }
-    QString tmpFile;
     if (!url.isLocalFile()) {
         KIO::FileCopyJob *copyjob = KIO::file_copy(url, QUrl::fromLocalFile(QDir::temp().absoluteFilePath(url.fileName())));
         doShowSpeechMessage(i18n("Downloading model..."), KMessageWidget::Information);
@@ -2127,7 +2152,7 @@ void KdenliveSettingsDialog::slotParseVoskDictionaries()
         dir = QDir(modelDirectory);
         if (!dir.cd(QStringLiteral("speechmodels"))) {
             qDebug()<<"=== /// CANNOT ACCESS SPEECH DICTIONARIES FOLDER";
-            pCore->voskModelUpdate({});
+            emit pCore->voskModelUpdate({});
             return;
         }
     } else {
@@ -2151,6 +2176,6 @@ void KdenliveSettingsDialog::slotParseVoskDictionaries()
     } else if (final.isEmpty()) {
         doShowSpeechMessage(i18n("Please add a speech model."), KMessageWidget::Information);
     }
-    pCore->voskModelUpdate(final);
+    emit pCore->voskModelUpdate(final);
 }
 
