@@ -1,22 +1,8 @@
-/***************************************************************************
- *                                                                         *
- *   Copyright (C) 2021 by Jean-Baptiste Mardelle (jb@kdenlive.org)        *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2021 Jean-Baptiste Mardelle <jb@kdenlive.org>
+
+SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "stabilizetask.h"
 #include "bin/bin.h"
@@ -38,7 +24,7 @@
 
 #include <klocalizedstring.h>
 
-StabilizeTask::StabilizeTask(const ObjectId &owner, const QString &binId, const QString &destination, int in, int out, bool autoAddClip, std::unordered_map<QString, QVariant> filterParams, QObject* object)
+StabilizeTask::StabilizeTask(const ObjectId &owner, const QString &binId, const QString &destination, int in, int out, std::pair<bool,bool> autoAddClip, std::unordered_map<QString, QVariant> filterParams, QObject* object)
     : AbstractTask(owner, AbstractTask::STABILIZEJOB, object)
     , m_binId(binId)
     , m_inPoint(in)
@@ -71,6 +57,8 @@ void StabilizeTask::start(QObject* object, bool force)
         }
         // Now we have to create the jobs objects. This is trickier than usual, since the parameters are different for each job (each clip has its own
         // destination). We have to construct a lambda that does that.
+        bool autoAdd = d->autoAddClip();
+        bool addToFolder = d->addClipInFolder();
         for (auto & id : binIds) {
             StabilizeTask* task = nullptr;
             ObjectId owner;
@@ -84,14 +72,14 @@ void StabilizeTask::start(QObject* object, bool force)
                 owner = ObjectId(ObjectType::BinClip, binData.first().toInt());
                 auto binClip = pCore->projectItemModel()->getClipByBinID(binData.first());
                 if (binClip) {
-                    task = new StabilizeTask(owner, binData.first(), destinations.at(id), binData.at(1).toInt(), binData.at(2).toInt(), d->autoAddClip(), filterParams, binClip.get());
+                    task = new StabilizeTask(owner, binData.first(), destinations.at(id), binData.at(1).toInt(), binData.at(2).toInt(), {autoAdd,addToFolder}, filterParams, binClip.get());
                 }
             } else {
                 // Process full clip
                 owner = ObjectId(ObjectType::BinClip, id.toInt());
                 auto binClip = pCore->projectItemModel()->getClipByBinID(id);
                 if (binClip) {
-                    task = new StabilizeTask(owner, id, destinations.at(id), -1, -1, d->autoAddClip(), filterParams, binClip.get());
+                    task = new StabilizeTask(owner, id, destinations.at(id), -1, -1, {autoAdd,addToFolder}, filterParams, binClip.get());
                 }
             }
             if (task) {
@@ -159,9 +147,9 @@ void StabilizeTask::run()
     for (const auto &it : m_filterParams) {
         qDebug()<<". . ."<<it.first<<" = "<<it.second;
         if (it.second.type() == QVariant::Double) {
-            producerArgs << QString("%1=%2").arg(it.first).arg(it.second.toDouble());
+            producerArgs << QString("%1=%2").arg(it.first, QString::number(it.second.toDouble()));
         } else {
-            producerArgs << QString("%1=%2").arg(it.first).arg(it.second.toString());
+            producerArgs << QString("%1=%2").arg(it.first, it.second.toString());
         }
     }
     QString targetFile = m_destination + QStringLiteral(".trf");
@@ -194,8 +182,8 @@ void StabilizeTask::run()
         }
         return;
     }
-    if (m_addToProject) {
-        QMetaObject::invokeMethod(pCore->bin(), "addProjectClipInFolder", Qt::QueuedConnection, Q_ARG(const QString&,m_destination), Q_ARG(const QString&,binClip->parent()->clipId()), Q_ARG(const QString&,i18n("Stabilized")));
+    if (m_addToProject.first) {
+        QMetaObject::invokeMethod(pCore->bin(), "addProjectClipInFolder", Qt::QueuedConnection, Q_ARG(QString,m_destination), Q_ARG(QString,binClip->parent()->clipId()), Q_ARG(QString,m_addToProject.second ? i18n("Stabilized") : QString()));
     }
 }
 
