@@ -1,13 +1,8 @@
 /*
-Copyright (C) 2012  Jean-Baptiste Mardelle <jb@kdenlive.org>
-Copyright (C) 2014  Till Theato <root@ttill.de>
-Copyright (C) 2020  Julius Künzel <jk.kdedev@smartlab.uber.space>
-This file is part of kdenlive. See www.kdenlive.org.
-
-This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
+SPDX-FileCopyrightText: 2012 Jean-Baptiste Mardelle <jb@kdenlive.org>
+SPDX-FileCopyrightText: 2014 Till Theato <root@ttill.de>
+SPDX-FileCopyrightText: 2020 Julius Künzel <jk.kdedev@smartlab.uber.space>
+SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #include "layoutmanagement.h"
@@ -345,7 +340,7 @@ void LayoutManagement::slotManageLayouts()
     QToolButton tb2(&d);
     tb2.setIcon(QIcon::fromTheme(QStringLiteral("go-up")));
     tb2.setAutoRaise(true);
-    connect(&tb2, &QToolButton::clicked, [&list]() {
+    connect(&tb2, &QToolButton::clicked, this, [&list]() {
         if (list.currentItem() && list.currentRow() > 0) {
             int updatedRow = list.currentRow() - 1;
             QListWidgetItem *item = list.takeItem(list.currentRow());
@@ -359,7 +354,7 @@ void LayoutManagement::slotManageLayouts()
     QToolButton tb3(&d);
     tb3.setIcon(QIcon::fromTheme(QStringLiteral("go-down")));
     tb3.setAutoRaise(true);
-    connect(&tb3, &QToolButton::clicked, [&list]() {
+    connect(&tb3, &QToolButton::clicked, this, [&list]() {
         if (list.currentItem() && list.currentRow() < list.count() - 1) {
             int updatedRow = list.currentRow() + 1;
             QListWidgetItem *item = list.takeItem(list.currentRow());
@@ -374,7 +369,7 @@ void LayoutManagement::slotManageLayouts()
     tb4.setIcon(QIcon::fromTheme(QStringLiteral("view-refresh")));
     tb4.setAutoRaise(true);
     tb4.setToolTip(i18n("Reset"));
-    connect(&tb4, &QToolButton::clicked, [this, &config, &list, &layouts, current]() {
+    connect(&tb4, &QToolButton::clicked, this, [this, &config, &list, &layouts, current]() {
         // Load default base layouts
         KConfig defaultConfig(QStringLiteral("kdenlivedefaultlayouts.rc"), KConfig::CascadeConfig, QStandardPaths::AppDataLocation);
         KConfigGroup defaultOrder(&defaultConfig, "Order");
@@ -419,7 +414,7 @@ void LayoutManagement::slotManageLayouts()
     tb5.setIcon(QIcon::fromTheme(QStringLiteral("document-import")));
     tb5.setAutoRaise(true);
     tb5.setToolTip(i18n("Import"));
-    connect(&tb5, &QToolButton::clicked, [this, &d, &list](){
+    connect(&tb5, &QToolButton::clicked, this, [this, &d, &list](){
         QScopedPointer<QFileDialog> fd(new QFileDialog(&d, i18n("Load Layout")));
         fd->setMimeTypeFilters(QStringList() << QStringLiteral("application/kdenlivelayout"));
         fd->setFileMode(QFileDialog::ExistingFile);
@@ -460,7 +455,7 @@ void LayoutManagement::slotManageLayouts()
     tb6.setIcon(QIcon::fromTheme(QStringLiteral("document-export")));
     tb6.setAutoRaise(true);
     tb6.setToolTip(i18n("Export selected"));
-    connect(&tb6, &QToolButton::clicked, [ &d, &list](){
+    connect(&tb6, &QToolButton::clicked, this, [ &d, &list](){
 
         if (!list.currentItem()) {
             // Error, no layout selected
@@ -506,7 +501,7 @@ void LayoutManagement::slotManageLayouts()
     });
     l2->addWidget(&tb6);
 
-    connect(&list, &QListWidget::currentRowChanged, [&list, &tb2, &tb3] (int row) {
+    connect(&list, &QListWidget::currentRowChanged, this, [&list, &tb2, &tb3] (int row) {
         tb2.setEnabled(row > 0);
         tb3.setEnabled(row < list.count() - 1);
     });
