@@ -234,7 +234,7 @@ private:
     QPoint m_offset;
     MonitorProxy *m_proxy;
     std::shared_ptr<Mlt::Producer> m_blackClip;
-    static void on_frame_show(mlt_consumer, void *self, mlt_frame frame);
+    static void on_frame_show(mlt_consumer, GLWidget* widget, mlt_event_data);
     static void on_frame_render(mlt_consumer, GLWidget *widget, mlt_frame frame);
     static void on_gl_frame_show(mlt_consumer, void *self, mlt_frame frame_ptr);
     static void on_gl_nosync_frame_show(mlt_consumer, void *self, mlt_frame frame_ptr);
