@@ -241,6 +241,12 @@ Monitor::Monitor(Kdenlive::MonitorId id, MonitorManager *manager, QWidget *paren
         m_recManager = new RecManager(this);
         connect(m_recManager, &RecManager::warningMessage, this, &Monitor::warningMessage);
         connect(m_recManager, &RecManager::addClipToProject, this, &Monitor::addClipToProject);
+        // Show timeline clip usage
+        connect(pCore.get(), &Core::clipInstanceResized, this, [this](const QString &binId) {
+            if (m_controller && activeClipId() == binId) {
+                m_controller->checkClipBounds();
+            }
+        });
 
         m_toolbar->addAction(manager->getAction(QStringLiteral("insert_project_tree")));
         m_toolbar->setToolTip(i18n("Insert Zone to Project Bin"));
@@ -1251,7 +1257,41 @@ void Monitor::slotExtractCurrentFrame(QString frameName, bool addToProject)
                                                                         m_controller->getProducerProperty(QStringLiteral("kdenlive:originalurl")), -1, -1,
                                                                         b != nullptr ? b->isChecked() : false);
             } else {
-                frame = m_glMonitor->getControllerProxy()->extractFrame(m_glMonitor->getCurrentPos(), QString(), -1, -1, b != nullptr ? b->isChecked() : false);
+                if (m_id == Kdenlive::ProjectMonitor) {
+                    // Check if we have proxied clips at position
+                    QStringList proxiedClips = pCore->window()->getCurrentTimeline()->model()->getProxiesAt(m_glMonitor->getCurrentPos());
+                    // Temporarily disable proxy on those clips
+                    QMap<QString, QString> existingProxies;
+                    if (!proxiedClips.isEmpty()) {
+                        existingProxies = pCore->currentDoc()->proxyClipsById(proxiedClips, false);
+                    }
+                    disconnect(m_glMonitor, &GLWidget::analyseFrame, this, &Monitor::frameUpdated);
+                    bool analysisStatus = m_glMonitor->sendFrameForAnalysis;
+                    m_glMonitor->sendFrameForAnalysis = true;
+                    if (m_captureConnection) {
+                        QObject::disconnect( m_captureConnection );
+                    }
+                    m_captureConnection = connect(m_glMonitor, &GLWidget::analyseFrame, [this, proxiedClips, selectedFile, existingProxies, addToProject, analysisStatus](const QImage &img) {
+                        m_glMonitor->sendFrameForAnalysis = analysisStatus;
+                        m_glMonitor->releaseAnalyse();
+                        img.save(selectedFile);
+                        // Re-enable proxy on those clips
+                        if (!proxiedClips.isEmpty()) {
+                            pCore->currentDoc()->proxyClipsById(proxiedClips, true, existingProxies);
+                        }
+                        QObject::disconnect( m_captureConnection );
+                        connect(m_glMonitor, &GLWidget::analyseFrame, this, &Monitor::frameUpdated);
+                        KRecentDirs::add(QStringLiteral(":KdenliveFramesFolder"), QUrl::fromLocalFile(selectedFile).adjusted(QUrl::RemoveFilename).toLocalFile());
+                        if (addToProject) {
+                            QString folderInfo = pCore->bin()->getCurrentFolder();
+                            pCore->bin()->droppedUrls(QList<QUrl> {QUrl::fromLocalFile(selectedFile)}, folderInfo);
+                        }
+                    });
+                    refreshMonitor();
+                    return;
+                } else {
+                    frame = m_glMonitor->getControllerProxy()->extractFrame(m_glMonitor->getCurrentPos(), QString(), -1, -1, b != nullptr ? b->isChecked() : false);
+                }
             }
             frame.save(selectedFile);
             if (b != nullptr) {
@@ -1650,6 +1690,10 @@ void Monitor::slotOpenClip(const std::shared_ptr<ProjectClip> &controller, int i
                    SLOT(checkOverlay()));
         disconnect(m_controller->getMarkerModel().get(), SIGNAL(rowsInserted(const QModelIndex &, int, int)), this, SLOT(checkOverlay()));
         disconnect(m_controller->getMarkerModel().get(), SIGNAL(rowsRemoved(const QModelIndex &, int, int)), this, SLOT(checkOverlay()));
+        if (m_controller->hasLimitedDuration()) {
+            disconnect(m_controller.get(), &ProjectClip::boundsChanged, m_glMonitor->getControllerProxy(), &MonitorProxy::updateClipBounds);
+            disconnect(m_controller.get(), &ProjectClip::registeredClipChanged, m_controller.get(), &ProjectClip::checkClipBounds);
+        }
     }
     disconnect(this, &Monitor::seekPosition, this, &Monitor::seekRemap);
     m_controller = controller;
@@ -1704,6 +1748,10 @@ void Monitor::slotOpenClip(const std::shared_ptr<ProjectClip> &controller, int i
             //m_audioChannels->menuAction()->setVisible(false);
         }
         connect(m_controller.get(), &ProjectClip::audioThumbReady, this, &Monitor::prepareAudioThumb);
+        if (m_controller->hasLimitedDuration()) {
+            connect(m_controller.get(), &ProjectClip::boundsChanged, m_glMonitor->getControllerProxy(), &MonitorProxy::updateClipBounds);
+            connect(m_controller.get(), &ProjectClip::registeredClipChanged, m_controller.get(), &ProjectClip::checkClipBounds);
+        }
         connect(m_controller->getMarkerModel().get(), SIGNAL(dataChanged(QModelIndex,QModelIndex,QVector<int>)), this,
                 SLOT(checkOverlay()));
         connect(m_controller->getMarkerModel().get(), SIGNAL(rowsInserted(QModelIndex,int,int)), this, SLOT(checkOverlay()));
