@@ -1,25 +1,12 @@
-/***************************************************************************
- *   Copyright (C) 2006 by Peter Penz                                      *
- *                 2012    Simon A. Eugster <simon.eu@gmail.com>           *
- *   peter.penz@gmx.at                                                     *
- *   Code borrowed from Dolphin, adapted (2008) to Kdenlive by             *
- *   Jean-Baptiste Mardelle, jb@kdenlive.org                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2006 Peter Penz <peter.penz@gmx.at>
+    SPDX-FileCopyrightText: 2008 Jean-Baptiste Mardelle <jb@kdenlive.org>
+    SPDX-FileCopyrightText: 2012 Simon A. Eugster <simon.eu@gmail.com>
+
+    Some code borrowed from Dolphin, adapted (2008) to Kdenlive
+
+    SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "statusbarmessagelabel.h"
 #include "kdenlivesettings.h"
@@ -232,7 +219,7 @@ bool StatusBarMessageLabel::slotMessageTimeout()
         }
     }
 
-    QColor bgColor = KStatefulBrush(KColorScheme::Window, KColorScheme::NegativeBackground).brush(m_container).color();
+    QColor bgColor = KStatefulBrush(KColorScheme::Window, KColorScheme::NegativeBackground).brush(m_container->palette()).color();
     const char *iconName = nullptr;
     m_container->setColor(m_container->palette().window().color());
     switch (m_currentMessage.type) {
