@@ -32,6 +32,7 @@ ClipModel::ClipModel(const std::shared_ptr<TimelineModel> &parent, std::shared_p
     , m_currentState(state)
     , m_speed(speed)
     , m_fakeTrack(-1)
+    , m_fakePosition(-1)
     , m_positionOffset(0)
     , m_subPlaylistIndex(0)
     , m_mixDuration(0)
@@ -147,7 +148,7 @@ void ClipModel::registerClipToBin(std::shared_ptr<Mlt::Producer> service, bool r
 void ClipModel::deregisterClipToBin()
 {
     std::shared_ptr<ProjectClip> binClip = pCore->projectItemModel()->getClipByBinID(m_binClipId);
-    binClip->deregisterTimelineClip(m_id);
+    binClip->deregisterTimelineClip(m_id, isAudioOnly());
 }
 
 ClipModel::~ClipModel() = default;
@@ -249,6 +250,9 @@ bool ClipModel::requestResize(int size, bool right, Fun &undo, Fun &redo, bool l
                     }
                 }
             }
+            if (logUndo && !m_endlessResize) {
+                emit pCore->clipInstanceResized(m_binClipId);
+            }
             return true;
         }
         return false;
@@ -294,6 +298,9 @@ bool ClipModel::requestResize(int size, bool right, Fun &undo, Fun &redo, bool l
                         }
                     }
                 }
+                if (logUndo && !m_endlessResize) {
+                    emit pCore->clipInstanceResized(m_binClipId);
+                }
                 return true;
             }
             qDebug()<<"============\n+++++++++++++++++\nREVRSE TRACK OP FAILED\n\n++++++++++++++++";
