@@ -280,6 +280,10 @@ public:
        @param clipId Id of the clip to test
     */
     int getClipIn(int clipId) const;
+    /** @brief Returns the in and playtime of a clip
+       @param clipId Id of the clip to test
+    */
+    QPoint getClipInDuration(int clipId) const;
 
     /** @brief Returns the clip state (audio/video only)
      */
@@ -435,6 +439,9 @@ public:
     /**  @brief Returns a list of the master effects zones
      */
     QVariantList getMasterEffectZones() const;
+    /**  @brief Returns a list of proxied clips at position pos
+     */
+    QStringList getProxiesAt(int position);
 
 protected:
     /** @brief Creates a new clip instance without inserting it.
@@ -499,7 +506,7 @@ public:
     Q_INVOKABLE int requestItemResize(int itemId, int size, bool right, bool logUndo = true, int snapDistance = -1, bool allowSingleResize = false);
 
     /** @brief Same function, but accumulates undo and redo and doesn't deal with snapping*/
-    bool requestItemResize(int itemId, int size, bool right, bool logUndo, Fun &undo, Fun &redo, bool blockUndo = false);
+    bool requestItemResize(int itemId, int &size, bool right, bool logUndo, Fun &undo, Fun &redo, bool blockUndo = false);
 
     /** @brief @todo TODO */
     Q_INVOKABLE int requestItemRippleResize(int itemId, int size, bool right, bool logUndo = true, int snapDistance = -1, bool allowSingleResize = false);
