@@ -1,23 +1,7 @@
-/***************************************************************************
- *   Copyright (C) 2017 by Nicolas Carion                                  *
- *   This file is part of Kdenlive. See www.kdenlive.org.                  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) version 3 or any later version accepted by the       *
- *   membership of KDE e.V. (or its successor approved  by the membership  *
- *   of KDE e.V.), which shall act as a proxy defined in Section 14 of     *
- *   version 3 of the license.                                             *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2017 Nicolas Carion
+    SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "transitiontreemodel.hpp"
 #include "abstractmodel/treeitem.hpp"
@@ -51,11 +35,10 @@ std::shared_ptr<TransitionTreeModel> TransitionTreeModel::construct(bool flat, Q
     for (const auto &transition : qAsConst(allTransitions)) {
         std::shared_ptr<TreeItem> targetCategory = compoCategory;
         AssetListType::AssetType type = TransitionsRepository::get()->getType(transition.first);
-        if (type == AssetListType::AssetType::AudioTransition || type == AssetListType::AssetType::VideoTransition) {
-            targetCategory = transCategory;
-        }
         if (flat) {
             targetCategory = self->rootItem;
+        } else if (type == AssetListType::AssetType::AudioTransition || type == AssetListType::AssetType::VideoTransition) {
+            targetCategory = transCategory;
         }
 
         // we create the data list corresponding to this transition
@@ -92,7 +75,7 @@ void TransitionTreeModel::setFavorite(const QModelIndex &index, bool favorite, b
     if (!index.isValid()) {
         return;
     }
-    std::shared_ptr<TreeItem> item = getItemById((int)index.internalId());
+    std::shared_ptr<TreeItem> item = getItemById(int(index.internalId()));
     if (isEffect && item->depth() == 1) {
         return;
     }
