@@ -1653,7 +1653,8 @@ TEST_CASE("Undo and Redo", "[ClipModel]")
         {
             std::function<bool(void)> undo = []() { return true; };
             std::function<bool(void)> redo = []() { return true; };
-            REQUIRE(timeline->requestItemResize(cid6, l - 5, true, true, undo, redo, false));
+            int size = l - 5;
+            REQUIRE(timeline->requestItemResize(cid6, size, true, true, undo, redo, false));
             pCore->pushUndo(undo, redo, QString());
         }
         auto state2 = [&]() {
@@ -1682,7 +1683,8 @@ TEST_CASE("Undo and Redo", "[ClipModel]")
         {
             std::function<bool(void)> undo = []() { return true; };
             std::function<bool(void)> redo = []() { return true; };
-            REQUIRE(timeline->requestItemResize(cid6, l - 6, false, true, undo, redo, false));
+            int size = l - 6;
+            REQUIRE(timeline->requestItemResize(cid6, size, false, true, undo, redo, false));
             pCore->pushUndo(undo, redo, QString());
         }
         auto state4 = [&]() {
